NLSL: expdat.f90 Source File

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

expdat.f90
Go to the documentation of this file.
1 c NLSL Version 1.9.0 beta 2/9/15
2 c----------------------------------------------------------------------
3 c ====================
4 c module EXPDAT
5 c ====================
6 c Experimental data used for least-squares fitting and associated
7 c parameters.
8 c
9 c NOTE: module nlsdim is used by this module.
10 c
11 c data : Experimental data points
12 c rmsn : Noise level for each spectrum
13 c sbi : Starting fields for each spectrum
14 c sdb : Field step size for each spectrum
15 c srng : Field range for each spectrum
16 c sb0 : Resonance field (for average g-value) for each spectrum
17 c sphs : Microwave phase for each spectrum
18 c spsi : Director tilt for each spectrum
19 c scale : Scale factor for each spectrum (calculated during fit)
20 c iform : Input format of each datafile
21 c ibase : Baseline correction method for each datafile
22 c nrmlz : "Normalized" flag for each spectrum (0=no)
23 c npts : Number of data points in each spectrum
24 c nft : Smallest power of 2 larger than npts
25 c idrv : Flag=1 if data are in 1st derivative form
26 c ixsp : Starting index of each spectrum in data array
27 c nspc : Number of spectra
28 c nwin : Number of open windows
29 c ndatot: Total number of points (all spectra)
30 c ishglb: Flag=1 if shifting enabled for all spectra
31 c dataid: Identification string for each datafile
32 c wndoid: Identification string for each window
33 c written: Flags whether current calculation has been written to disk
34 c
35 c----------------------------------------------------------------------
36 module expdat
37 use nlsdim
38 implicit none
39 c
40 double precision, save :: data(mxpt),spltmp(mxinp,3),rmsn(mxspc),
41 # sbi(mxspc),sdb(mxspc),srng(mxspc),shft(mxspc),
42 # sb0(mxspc),sphs(mxspc),spsi(mxspc),slb(mxspc),
43 # tmpshft(mxspc)
44 c
45 integer, save :: iform(mxspc),ibase(mxspc),nft(mxspc),
46 # npts(mxspc),ishft(mxspc),idrv(mxspc),ixsp(mxspc),
47 # nrmlz(mxspc),nspc,nwin,ndatot,ishglb,
48 # inform,bcmode,drmode,
49 # nspline,shftflg,normflg,written
50 c
51 character*30, save :: dataid(mxspc)
52 character*20, save :: wndoid(mxspc)
53 c
54 end module expdat
expdat::nrmlz
integer, dimension(mxspc), save nrmlz
Definition: expdat.f90:45
nlsdim::mxpt
integer, parameter mxpt
Definition: nlsdim.f90:39
expdat::nwin
integer, save nwin
Definition: expdat.f90:45
expdat::sbi
double precision, dimension(mxspc), save sbi
Definition: expdat.f90:40
expdat::drmode
integer, save drmode
Definition: expdat.f90:45
expdat::ndatot
integer, save ndatot
Definition: expdat.f90:45
expdat::sdb
double precision, dimension(mxspc), save sdb
Definition: expdat.f90:40
expdat::nft
integer, dimension(mxspc), save nft
Definition: expdat.f90:45
expdat::ixsp
integer, dimension(mxspc), save ixsp
Definition: expdat.f90:45
expdat::inform
integer, save inform
Definition: expdat.f90:45
expdat::srng
double precision, dimension(mxspc), save srng
Definition: expdat.f90:40
expdat::ishft
integer, dimension(mxspc), save ishft
Definition: expdat.f90:45
expdat::ibase
integer, dimension(mxspc), save ibase
Definition: expdat.f90:45
expdat::tmpshft
double precision, dimension(mxspc), save tmpshft
Definition: expdat.f90:40
expdat::shft
double precision, dimension(mxspc), save shft
Definition: expdat.f90:40
expdat::dataid
character *30, dimension(mxspc), save dataid
Definition: expdat.f90:51
expdat::spsi
double precision, dimension(mxspc), save spsi
Definition: expdat.f90:40
expdat::wndoid
character *20, dimension(mxspc), save wndoid
Definition: expdat.f90:52
expdat::normflg
integer, save normflg
Definition: expdat.f90:45
nlsdim::mxspc
integer, parameter mxspc
Definition: nlsdim.f90:39
expdat::bcmode
integer, save bcmode
Definition: expdat.f90:45
expdat::written
integer, save written
Definition: expdat.f90:45
expdat::data
double precision, dimension(mxpt), save data
Definition: expdat.f90:40
expdat::nspc
integer, save nspc
Definition: expdat.f90:45
expdat::sphs
double precision, dimension(mxspc), save sphs
Definition: expdat.f90:40
expdat::spltmp
double precision, dimension(mxinp, 3), save spltmp
Definition: expdat.f90:40
expdat::nspline
integer, save nspline
Definition: expdat.f90:45
expdat::idrv
integer, dimension(mxspc), save idrv
Definition: expdat.f90:45
expdat
Definition: expdat.f90:36
expdat::iform
integer, dimension(mxspc), save iform
Definition: expdat.f90:45
nlsdim
Definition: nlsdim.f90:36
expdat::sb0
double precision, dimension(mxspc), save sb0
Definition: expdat.f90:40
expdat::rmsn
double precision, dimension(mxspc), save rmsn
Definition: expdat.f90:40
expdat::shftflg
integer, save shftflg
Definition: expdat.f90:45
expdat::npts
integer, dimension(mxspc), save npts
Definition: expdat.f90:45
expdat::slb
double precision, dimension(mxspc), save slb
Definition: expdat.f90:40
expdat::ishglb
integer, save ishglb
Definition: expdat.f90:45
nlsdim::mxinp
integer, parameter mxinp
Definition: nlsdim.f90:39